@@ -24,8 +24,15 @@ describe("issues", function () {
 
         context("when comparing different jQuery objects", function () {
             it("should return false", function () {
+                jQuery(`
+                    <body>
+                        <p id='test1'>My <em>old</em> text</p>
+                        <p id='test2'>My <em>new</em> text</p>
+                    </body>
+                `).appendTo("html");
+
                 assert.isFalse(
-                    samsam.deepEqual(jQuery("head"), jQuery("body"))
+                    samsam.deepEqual(jQuery("#test1"), jQuery("#test2"))
                 );
             });
         });
